@@ -66,6 +66,17 @@ int ln_parseFloat(const char *str, size_t strlen, size_t *offs, const ln_fieldLi
 int ln_parseHexNumber(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
 
 
+/** 
+ * Parser for kernel timestamps.
+ */
+int ln_parseKernelTimestamp(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/** 
+ * Parser for whitespace
+ */
+int ln_parseWhitespace(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+
 /** 
  * Parser for Words (SP-terminated strings).
  */
@@ -120,17 +131,66 @@ int ln_parseISODate(const char *str, size_t strlen, size_t *offs, const ln_field
  */
 int ln_parseTime12hr(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
 
-
 /** 
  * Parse a timestamp in 24hr format.
  */
 int ln_parseTime24hr(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
 
+/** 
+ * Parse a duration.
+ */
+int ln_parseDuration(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
 /** 
  * Parser for IPv4 addresses.
  */
 int ln_parseIPv4(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
 
+/** 
+ * Parser for IPv6 addresses.
+ */
+int ln_parseIPv6(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/** 
+ * Parse JSON.
+ */
+int ln_parseJSON(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/** 
+ * Parse cee syslog.
+ */
+int ln_parseCEESyslog(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/** 
+ * Parse iptables log, the new way
+ */
+int ln_parsev2IPTables(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/** 
+ * Parser Cisco interface specifiers
+ */
+int ln_parseCiscoInterfaceSpec(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/** 
+ * Parser 48 bit MAC layer addresses.
+ */
+int ln_parseMAC48(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/**
+ * Parser for CEF version 0.
+ */
+int ln_parseCEF(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/**
+ * Parser for Checkpoint LEA.
+ */
+int ln_parseCheckpointLEA(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
+/**
+ * Parser for name/value pairs.
+ */
+int ln_parseNameValue(const char *str, size_t strlen, size_t *offs, const ln_fieldList_t *node, size_t *parsed, struct json_object **value);
+
 /** 
  * Get all tokens separated by tokenizer-string as array.
  */
