@@ -1,7 +1,9 @@
 # added 2014-11-14 by singh.janmejay
 # This file is part of the liblognorm project, released under ASL 2.0
 export ln_opts='-oallowRegex'
-source ./exec.sh $0 "invalid type for regex field with everything else defaulted"
+. $srcdir/exec.sh
+
+test_def $0 "invalid type for regex field with everything else defaulted"
 
 add_rule 'rule=:%first:regex:[a-z]+:Q%'
 execute 'foo'
@@ -37,3 +39,7 @@ add_rule 'rule=:%first:regex:::::%%%'
 execute 'foo'
 assert_output_contains '"originalmsg": "foo"'
 assert_output_contains '"unparsed-data": "foo"'
+
+
+cleanup_tmp_files
+
